TypeDef

Struct TypeDef 

pub struct TypeDef { /* private fields */ }
Available on crate feature dyn-abi only.
An EIP-712 type definition.

Implementations

Source

impl TypeDef

pub fn new<S>(type_name: S, props: Vec<PropertyDef>) -> Result<TypeDef, Error>
where S: Into<String>,

Available on crate feature eip712 only.

Instantiate a new type definition, checking that the type name is a valid root type.

pub const fn new_unchecked( type_name: String, props: Vec<PropertyDef>, ) -> TypeDef

Available on crate feature eip712 only.

Instantiate a new type definition, without checking that the type name is a valid root type. This may result in bad behavior in a resolver.

pub fn type_name(&self) -> &str

Available on crate feature eip712 only.

Returns the type name of the type definition.

pub fn props(&self) -> &[PropertyDef]

Available on crate feature eip712 only.

Returns the property definitions of the type definition.

pub fn prop_names(&self) -> impl Iterator<Item = &str>

Available on crate feature eip712 only.

Returns the property names of the type definition.

pub fn prop_root_types(&self) -> impl Iterator<Item = &str>

Available on crate feature eip712 only.

Returns the root property types of the type definition.

pub fn prop_types(&self) -> impl Iterator<Item = &str>

Available on crate feature eip712 only.

Returns the property types of the type definition.

pub fn eip712_encode_type(&self) -> String

Available on crate feature eip712 only.

Produces the EIP-712 encodeType typestring for this type definition.

pub fn fmt_eip712_encode_type(&self, f: &mut impl Write) -> Result<(), Error>

Available on crate feature eip712 only.

Formats the EIP-712 encodeType typestring for this type definition into f.

pub fn props_bytes_len(&self) -> usize

Available on crate feature eip712 only.

Returns the number of bytes that the properties of this type definition will take up when formatted in the EIP-712 encodeType typestring.

pub fn root_type(&self) -> RootType<'_>

Available on crate feature eip712 only.

Return the root type.