pub struct RpcWithBlock<Params, Resp, Output = Resp, Map = fn(Resp) -> Output>{ /* private fields */ }providers only.Expand description
A struct that takes an optional BlockId parameter.
This resolves to a ProviderCall that will execute the call on the specified block.
By default this will use “latest”.
Implementations
Sourceimpl<Params, Resp, Output, Map> RpcWithBlock<Params, Resp, Output, Map>
impl<Params, Resp, Output, Map> RpcWithBlock<Params, Resp, Output, Map>
Sourcepub fn new_rpc(
inner: RpcCall<Params, Resp, Output, Map>,
) -> RpcWithBlock<Params, Resp, Output, Map>
pub fn new_rpc( inner: RpcCall<Params, Resp, Output, Map>, ) -> RpcWithBlock<Params, Resp, Output, Map>
Create a new RpcWithBlock from a RpcCall.
Sourcepub fn new_provider<F>(get_call: F) -> RpcWithBlock<Params, Resp, Output, Map>
pub fn new_provider<F>(get_call: F) -> RpcWithBlock<Params, Resp, Output, Map>
Create a new RpcWithBlock from a closure producing a ProviderCall.
Sourceimpl<Params, Resp, Output, Map> RpcWithBlock<Params, Resp, Output, Map>
impl<Params, Resp, Output, Map> RpcWithBlock<Params, Resp, Output, Map>
Sourcepub const fn block_id(
self,
block_id: BlockId,
) -> RpcWithBlock<Params, Resp, Output, Map>
pub const fn block_id( self, block_id: BlockId, ) -> RpcWithBlock<Params, Resp, Output, Map>
Set the block id.
Sourcepub const fn pending(self) -> RpcWithBlock<Params, Resp, Output, Map>
pub const fn pending(self) -> RpcWithBlock<Params, Resp, Output, Map>
Set the block id to “pending”.
Sourcepub const fn latest(self) -> RpcWithBlock<Params, Resp, Output, Map>
pub const fn latest(self) -> RpcWithBlock<Params, Resp, Output, Map>
Set the block id to “latest”.
Sourcepub const fn earliest(self) -> RpcWithBlock<Params, Resp, Output, Map>
pub const fn earliest(self) -> RpcWithBlock<Params, Resp, Output, Map>
Set the block id to “earliest”.
Sourcepub const fn finalized(self) -> RpcWithBlock<Params, Resp, Output, Map>
pub const fn finalized(self) -> RpcWithBlock<Params, Resp, Output, Map>
Set the block id to “finalized”.
Sourcepub const fn safe(self) -> RpcWithBlock<Params, Resp, Output, Map>
pub const fn safe(self) -> RpcWithBlock<Params, Resp, Output, Map>
Set the block id to “safe”.
Sourcepub const fn number(
self,
number: u64,
) -> RpcWithBlock<Params, Resp, Output, Map>
pub const fn number( self, number: u64, ) -> RpcWithBlock<Params, Resp, Output, Map>
Set the block id to a specific height.
Sourcepub const fn hash(
self,
hash: FixedBytes<32>,
) -> RpcWithBlock<Params, Resp, Output, Map>
pub const fn hash( self, hash: FixedBytes<32>, ) -> RpcWithBlock<Params, Resp, Output, Map>
Set the block id to a specific hash, without requiring the hash be part of the canonical chain.
Sourcepub const fn hash_canonical(
self,
hash: FixedBytes<32>,
) -> RpcWithBlock<Params, Resp, Output, Map>
pub const fn hash_canonical( self, hash: FixedBytes<32>, ) -> RpcWithBlock<Params, Resp, Output, Map>
Set the block id to a specific hash and require the hash be part of the canonical chain.