SubFullBlocks

Struct SubFullBlocks 

pub struct SubFullBlocks<N>
where N: Network,
{ /* private fields */ }
Available on crate features providers and pubsub only.
A builder type for subscribing to full blocks i.e alloy_network_primitives::BlockResponse, and not just alloy_network_primitives::HeaderResponse.

By default this subscribes to block with tx hashes only. Use SubFullBlocks::full to subscribe to blocks with full transactions.

Implementations

Source

impl<N> SubFullBlocks<N>
where N: Network,

pub const fn new( sub: GetSubscription<(SubscriptionKind,), <N as Network>::HeaderResponse>, client: Weak<RpcClientInner>, ) -> SubFullBlocks<N>

Create a new SubFullBlocks subscription with the given super::GetSubscription.

By default, this subscribes to block with tx hashes only. Use SubFullBlocks::full to subscribe to blocks with full transactions.

pub const fn full(self) -> SubFullBlocks<N>

Subscribe to blocks with full transactions.

pub const fn hashes(self) -> SubFullBlocks<N>

Subscribe to blocks with transaction hashes only.

pub fn channel_size(self, size: usize) -> SubFullBlocks<N>

Set the channel size

pub async fn into_stream( self, ) -> Result<impl Stream<Item = Result<<N as Network>::BlockResponse, RpcError<TransportErrorKind>>> + Unpin, RpcError<TransportErrorKind>>

Subscribe to the inner stream of headers and map them to block responses.