pub struct Writer<B> { /* private fields */ }Available on crate feature
rlp only.Expand description
A BufMut adapter which implements io::Write for the inner value.
This struct is generally created by calling writer() on BufMut. See
documentation of writer() for more
details.
Implementations
Sourceimpl<B> Writer<B>where
B: BufMut,
impl<B> Writer<B>where
B: BufMut,
Sourcepub fn get_ref(&self) -> &B
Available on crate features signers and signer-gcp only.
pub fn get_ref(&self) -> &B
signers and signer-gcp only.Gets a reference to the underlying BufMut.
It is inadvisable to directly write to the underlying BufMut.
Examples
use bytes::BufMut;
let buf = Vec::with_capacity(1024).writer();
assert_eq!(1024, buf.get_ref().capacity());Sourcepub fn get_mut(&mut self) -> &mut B
Available on crate features signers and signer-gcp only.
pub fn get_mut(&mut self) -> &mut B
signers and signer-gcp only.Gets a mutable reference to the underlying BufMut.
It is inadvisable to directly write to the underlying BufMut.
Examples
use bytes::BufMut;
let mut buf = vec![].writer();
buf.get_mut().reserve(1024);
assert_eq!(1024, buf.get_ref().capacity());Sourcepub fn into_inner(self) -> B
Available on crate features signers and signer-gcp only.
pub fn into_inner(self) -> B
signers and signer-gcp only.Consumes this Writer, returning the underlying value.
Examples
use bytes::BufMut;
use std::io;
let mut buf = vec![].writer();
let mut src = &b"hello world"[..];
io::copy(&mut src, &mut buf).unwrap();
let buf = buf.into_inner();
assert_eq!(*buf, b"hello world"[..]);Trait Implementations
Sourceimpl<B> Write for Writer<B>where
B: BufMut,
impl<B> Write for Writer<B>where
B: BufMut,
Sourcefn write(&mut self, src: &[u8]) -> Result<usize, Error>
fn write(&mut self, src: &[u8]) -> Result<usize, Error>
Writes a buffer into this writer, returning how many bytes were written. Read more
Sourcefn flush(&mut self) -> Result<(), Error>
fn flush(&mut self) -> Result<(), Error>
Flushes this output stream, ensuring that all intermediately buffered
contents reach their destination. Read more
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector)1.0.0 · Sourcefn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
fn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
Attempts to write an entire buffer into this writer. Read more
Sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
🔬This is a nightly-only experimental API. (
write_all_vectored)Attempts to write multiple buffers into this writer. Read more