pub struct TypeDef { /* private fields */ }dyn-abi only.Expand description
An EIP-712 type definition.
Implementations
Sourceimpl TypeDef
impl TypeDef
Sourcepub fn new<S>(type_name: S, props: Vec<PropertyDef>) -> Result<TypeDef, Error>
Available on crate feature eip712 only.
pub fn new<S>(type_name: S, props: Vec<PropertyDef>) -> Result<TypeDef, Error>
eip712 only.Instantiate a new type definition, checking that the type name is a valid root type.
Sourcepub const fn new_unchecked(
type_name: String,
props: Vec<PropertyDef>,
) -> TypeDef
Available on crate feature eip712 only.
pub const fn new_unchecked( type_name: String, props: Vec<PropertyDef>, ) -> TypeDef
eip712 only.Instantiate a new type definition, without checking that the type name is a valid root type. This may result in bad behavior in a resolver.
Sourcepub fn type_name(&self) -> &str
Available on crate feature eip712 only.
pub fn type_name(&self) -> &str
eip712 only.Returns the type name of the type definition.
Sourcepub fn props(&self) -> &[PropertyDef]
Available on crate feature eip712 only.
pub fn props(&self) -> &[PropertyDef]
eip712 only.Returns the property definitions of the type definition.
Sourcepub fn prop_names(&self) -> impl Iterator<Item = &str>
Available on crate feature eip712 only.
pub fn prop_names(&self) -> impl Iterator<Item = &str>
eip712 only.Returns the property names of the type definition.
Sourcepub fn prop_root_types(&self) -> impl Iterator<Item = &str>
Available on crate feature eip712 only.
pub fn prop_root_types(&self) -> impl Iterator<Item = &str>
eip712 only.Returns the root property types of the type definition.
Sourcepub fn prop_types(&self) -> impl Iterator<Item = &str>
Available on crate feature eip712 only.
pub fn prop_types(&self) -> impl Iterator<Item = &str>
eip712 only.Returns the property types of the type definition.
Sourcepub fn eip712_encode_type(&self) -> String
Available on crate feature eip712 only.
pub fn eip712_encode_type(&self) -> String
eip712 only.Produces the EIP-712 encodeType typestring for this type definition.
Sourcepub fn fmt_eip712_encode_type(&self, f: &mut impl Write) -> Result<(), Error>
Available on crate feature eip712 only.
pub fn fmt_eip712_encode_type(&self, f: &mut impl Write) -> Result<(), Error>
eip712 only.Formats the EIP-712 encodeType typestring for this type definition
into f.
Sourcepub fn props_bytes_len(&self) -> usize
Available on crate feature eip712 only.
pub fn props_bytes_len(&self) -> usize
eip712 only.Returns the number of bytes that the properties of this type definition
will take up when formatted in the EIP-712 encodeType typestring.