pub struct ProviderBuilder<L, F, N = Ethereum> { /* private fields */ }providers only.Expand description
A builder for constructing a Provider from various layers.
This type is similar to tower::ServiceBuilder, with extra complication
around maintaining the network and transport types.
The ProviderBuilder can be instantiated in two ways, using ProviderBuilder::new() or
ProviderBuilder::default().
ProviderBuilder::new() will create a new ProviderBuilder with the RecommendedFillers
enabled, whereas ProviderBuilder::default() will instantiate it in its vanilla
ProviderBuilder form i.e with no fillers enabled.
Implementations
Sourceimpl ProviderBuilder<Identity, JoinFill<Identity, <Ethereum as RecommendedFillers>::RecommendedFillers>>
impl ProviderBuilder<Identity, JoinFill<Identity, <Ethereum as RecommendedFillers>::RecommendedFillers>>
Sourcepub fn new() -> ProviderBuilder<Identity, JoinFill<Identity, <Ethereum as RecommendedFillers>::RecommendedFillers>>
pub fn new() -> ProviderBuilder<Identity, JoinFill<Identity, <Ethereum as RecommendedFillers>::RecommendedFillers>>
Create a new ProviderBuilder with the recommended filler enabled.
Recommended fillers are preconfigured set of fillers that handle gas estimation, nonce management, and chain-id fetching.
Building a provider with this setting enabled will return a crate::fillers::FillProvider
with crate::utils::JoinedRecommendedFillers.
You can opt-out of using these fillers by using the .disable_recommended_fillers() method.
Sourcepub fn disable_recommended_fillers(self) -> ProviderBuilder<Identity, Identity>
pub fn disable_recommended_fillers(self) -> ProviderBuilder<Identity, Identity>
Opt-out of the recommended fillers by resetting the fillers stack in the
ProviderBuilder.
This is equivalent to creating the builder using ProviderBuilder::default().
Sourceimpl ProviderBuilder<Identity, Identity>
impl ProviderBuilder<Identity, Identity>
Sourcepub fn new_with_network<Net>() -> ProviderBuilder<Identity, JoinFill<Identity, <Net as RecommendedFillers>::RecommendedFillers>, Net>where
Net: RecommendedFillers,
pub fn new_with_network<Net>() -> ProviderBuilder<Identity, JoinFill<Identity, <Net as RecommendedFillers>::RecommendedFillers>, Net>where
Net: RecommendedFillers,
Create a new ProviderBuilder with the RecommendedFillers for the provided
Network.
Sourceimpl<L, N> ProviderBuilder<L, Identity, N>where
N: Network,
impl<L, N> ProviderBuilder<L, Identity, N>where
N: Network,
Sourcepub fn with_recommended_fillers(
self,
) -> ProviderBuilder<L, JoinFill<Identity, <N as RecommendedFillers>::RecommendedFillers>, N>where
N: RecommendedFillers,
pub fn with_recommended_fillers(
self,
) -> ProviderBuilder<L, JoinFill<Identity, <N as RecommendedFillers>::RecommendedFillers>, N>where
N: RecommendedFillers,
Add preconfigured set of layers handling gas estimation, nonce management, and chain-id fetching.
Sourceimpl<L, F, N> ProviderBuilder<L, F, N>
impl<L, F, N> ProviderBuilder<L, F, N>
Sourcepub fn apply<T>(self, f: impl FnOnce(ProviderBuilder<L, F, N>) -> T) -> T
pub fn apply<T>(self, f: impl FnOnce(ProviderBuilder<L, F, N>) -> T) -> T
Apply a function to this builder.
This is useful for extracting reusable builder-style helper functions without manually
reconstructing the ProviderBuilder.
Sourcepub fn map_layer<L2>(self, f: impl FnOnce(L) -> L2) -> ProviderBuilder<L2, F, N>
pub fn map_layer<L2>(self, f: impl FnOnce(L) -> L2) -> ProviderBuilder<L2, F, N>
Map the layer stack to a new type.
This is useful for customizing or replacing the accumulated layers in a reusable helper.
Sourcepub fn map_filler<F2>(
self,
f: impl FnOnce(F) -> F2,
) -> ProviderBuilder<L, F2, N>
pub fn map_filler<F2>( self, f: impl FnOnce(F) -> F2, ) -> ProviderBuilder<L, F2, N>
Map the filler stack to a new type.
This is useful for customizing or replacing the accumulated fillers in a reusable helper.
Sourcepub fn layer<Inner>(
self,
layer: Inner,
) -> ProviderBuilder<Stack<Inner, L>, F, N>
pub fn layer<Inner>( self, layer: Inner, ) -> ProviderBuilder<Stack<Inner, L>, F, N>
Add a layer to the stack being built. This is similar to
tower::ServiceBuilder::layer.
Note:
Layers are added in outer-to-inner order, as in
tower::ServiceBuilder. The first layer added will be the first to
see the request.
Sourcepub fn filler<F2>(self, filler: F2) -> ProviderBuilder<L, JoinFill<F, F2>, N>
pub fn filler<F2>(self, filler: F2) -> ProviderBuilder<L, JoinFill<F, F2>, N>
Add a transaction filler to the stack being built. Transaction fillers are used to fill in missing fields on transactions before they are sent, and are all joined to form the outermost layer of the stack.
Sourcepub fn network<Net>(
self,
) -> ProviderBuilder<L, JoinFill<Identity, <Net as RecommendedFillers>::RecommendedFillers>, Net>where
Net: RecommendedFillers,
pub fn network<Net>(
self,
) -> ProviderBuilder<L, JoinFill<Identity, <Net as RecommendedFillers>::RecommendedFillers>, Net>where
Net: RecommendedFillers,
Change the network.
By default, the network is Ethereum. This method must be called to configure a different
network.
This replaces the filler stack with the target network’s recommended fillers. Any custom
fillers should be added after calling .network().
builder.network::<Arbitrum>()Sourcepub fn with_chain(
self,
chain: NamedChain,
) -> ProviderBuilder<Stack<ChainLayer, L>, F, N>
pub fn with_chain( self, chain: NamedChain, ) -> ProviderBuilder<Stack<ChainLayer, L>, F, N>
Add a chain layer to the stack being built. The layer will set the client’s poll interval based on the average block time for this chain.
Does nothing to the client with a local transport.
Sourcepub fn with_blob_gas_estimation(
self,
) -> ProviderBuilder<L, JoinFill<F, BlobGasFiller>, N>
pub fn with_blob_gas_estimation( self, ) -> ProviderBuilder<L, JoinFill<F, BlobGasFiller>, N>
Add blob gas estimation to the stack being built.
See BlobGasFiller for more information.
Sourcepub fn with_blob_gas_estimator(
self,
estimator: BlobGasEstimator,
) -> ProviderBuilder<L, JoinFill<F, BlobGasFiller>, N>
pub fn with_blob_gas_estimator( self, estimator: BlobGasEstimator, ) -> ProviderBuilder<L, JoinFill<F, BlobGasFiller>, N>
Add blob gas estimation to the stack being built, using the provided estimator.
See BlobGasFiller and BlobGasEstimator for more information.
Sourcepub fn with_gas_estimation(
self,
) -> ProviderBuilder<L, JoinFill<F, GasFiller>, N>
pub fn with_gas_estimation( self, ) -> ProviderBuilder<L, JoinFill<F, GasFiller>, N>
Add gas estimation to the stack being built.
See GasFiller for more information.
Sourcepub fn with_eip1559_estimator(
self,
estimator: Eip1559Estimator,
) -> ProviderBuilder<L, JoinFill<F, GasFiller>, N>
pub fn with_eip1559_estimator( self, estimator: Eip1559Estimator, ) -> ProviderBuilder<L, JoinFill<F, GasFiller>, N>
Add EIP-1559 gas estimation to the stack being built, using the provided estimator.
See GasFiller and Eip1559Estimator for more information.
Sourcepub fn with_nonce_management<M>(
self,
nonce_manager: M,
) -> ProviderBuilder<L, JoinFill<F, NonceFiller<M>>, N>where
M: NonceManager,
pub fn with_nonce_management<M>(
self,
nonce_manager: M,
) -> ProviderBuilder<L, JoinFill<F, NonceFiller<M>>, N>where
M: NonceManager,
Add nonce management to the stack being built.
See NonceFiller for more information.
Sourcepub fn with_simple_nonce_management(
self,
) -> ProviderBuilder<L, JoinFill<F, NonceFiller<SimpleNonceManager>>, N>
pub fn with_simple_nonce_management( self, ) -> ProviderBuilder<L, JoinFill<F, NonceFiller<SimpleNonceManager>>, N>
Add simple nonce management to the stack being built.
See SimpleNonceManager for more information.
Sourcepub fn with_cached_nonce_management(
self,
) -> ProviderBuilder<L, JoinFill<F, NonceFiller>, N>
pub fn with_cached_nonce_management( self, ) -> ProviderBuilder<L, JoinFill<F, NonceFiller>, N>
Add cached nonce management to the stack being built.
See CachedNonceManager for more information.
Sourcepub fn fetch_chain_id(self) -> ProviderBuilder<L, JoinFill<F, ChainIdFiller>, N>
pub fn fetch_chain_id(self) -> ProviderBuilder<L, JoinFill<F, ChainIdFiller>, N>
Add a chain ID filler to the stack being built. The filler will attempt
to fetch the chain ID from the provider using
Provider::get_chain_id. the first time a transaction is prepared,
and will cache it for future transactions.
Sourcepub fn with_chain_id(
self,
chain_id: u64,
) -> ProviderBuilder<L, JoinFill<F, ChainIdFiller>, N>
pub fn with_chain_id( self, chain_id: u64, ) -> ProviderBuilder<L, JoinFill<F, ChainIdFiller>, N>
Add a specific chain ID to the stack being built. The filler will
fill transactions with the provided chain ID, regardless of the chain ID
that the provider reports via Provider::get_chain_id.
Sourcepub fn wallet<W>(
self,
wallet: W,
) -> ProviderBuilder<L, JoinFill<F, WalletFiller<<W as IntoWallet<N>>::NetworkWallet>>, N>where
W: IntoWallet<N>,
N: Network,
pub fn wallet<W>(
self,
wallet: W,
) -> ProviderBuilder<L, JoinFill<F, WalletFiller<<W as IntoWallet<N>>::NetworkWallet>>, N>where
W: IntoWallet<N>,
N: Network,
Add a wallet layer to the stack being built.
See WalletFiller.
Sourcepub fn with_call_batching(
self,
) -> ProviderBuilder<Stack<CallBatchLayer, L>, F, N>
pub fn with_call_batching( self, ) -> ProviderBuilder<Stack<CallBatchLayer, L>, F, N>
Aggregate multiple eth_call requests into a single batch request using Multicall3.
See CallBatchLayer for more information.
Sourcepub fn with_arbitrum_call_batching(
self,
) -> ProviderBuilder<Stack<CallBatchLayer, L>, F, N>
pub fn with_arbitrum_call_batching( self, ) -> ProviderBuilder<Stack<CallBatchLayer, L>, F, N>
Aggregate multiple eth_call requests with block number queries done by calling Arbsym
precompile.
See CallBatchLayer for more information.
Sourcepub fn with_caching(
self,
max_items: u32,
) -> ProviderBuilder<Stack<CacheLayer, L>, F, N>
Available on non-target_family=wasm only.
pub fn with_caching( self, max_items: u32, ) -> ProviderBuilder<Stack<CacheLayer, L>, F, N>
target_family=wasm only.Add response caching to the stack being built with the specified maximum cache size.
See CacheLayer for more information.
Sourcepub fn with_default_caching(self) -> ProviderBuilder<Stack<CacheLayer, L>, F, N>
Available on non-target_family=wasm only.
pub fn with_default_caching(self) -> ProviderBuilder<Stack<CacheLayer, L>, F, N>
target_family=wasm only.Add response caching to the stack being built with a default cache size of 100 items.
See CacheLayer for more information.
Sourcepub fn with_default_block(
self,
block_id: BlockId,
) -> ProviderBuilder<Stack<BlockIdLayer, L>, F, N>
pub fn with_default_block( self, block_id: BlockId, ) -> ProviderBuilder<Stack<BlockIdLayer, L>, F, N>
Set a default BlockId for eth_call and eth_estimateGas.
Sourcepub fn connect_provider<P>(
self,
provider: P,
) -> <F as ProviderLayer<<L as ProviderLayer<P, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<P, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<P, N>>::Provider, N>,
P: Provider<N>,
N: Network,
pub fn connect_provider<P>(
self,
provider: P,
) -> <F as ProviderLayer<<L as ProviderLayer<P, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<P, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<P, N>>::Provider, N>,
P: Provider<N>,
N: Network,
Sourcepub fn connect_client(
self,
client: RpcClient,
) -> <F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
pub fn connect_client(
self,
client: RpcClient,
) -> <F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
Sourcepub fn connect_mocked_client(
self,
asserter: Asserter,
) -> <F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
pub fn connect_mocked_client(
self,
asserter: Asserter,
) -> <F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
Sourcepub async fn connect(
self,
s: &str,
) -> Result<<F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Provider, RpcError<TransportErrorKind>>where
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
pub async fn connect(
self,
s: &str,
) -> Result<<F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Provider, RpcError<TransportErrorKind>>where
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
Finish the layer stack by providing a connection string for a built-in
transport type, outputting the final Provider type with all stack
components.
Sourcepub async fn connect_with_config(
self,
s: &str,
config: ConnectionConfig,
) -> Result<<F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Provider, RpcError<TransportErrorKind>>where
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
pub async fn connect_with_config(
self,
s: &str,
config: ConnectionConfig,
) -> Result<<F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Provider, RpcError<TransportErrorKind>>where
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
Finish the layer stack by providing a connection string with custom configuration.
This method allows for fine-grained control over connection settings
such as authentication, retry behavior, and transport-specific options.
The transport type is extracted from the connection string and configured
using the provided ConnectionConfig.
Examples
use alloy_provider::{ConnectionConfig, ProviderBuilder};
use alloy_transport::Authorization;
use std::time::Duration;
let config = ConnectionConfig::new()
.with_auth(Authorization::bearer("my-token"))
.with_max_retries(3)
.with_retry_interval(Duration::from_secs(2));
let provider =
ProviderBuilder::new().connect_with_config("ws://localhost:8545", config).await?;Sourcepub async fn connect_with<C>(
self,
connect: &C,
) -> Result<<F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Provider, RpcError<TransportErrorKind>>where
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
C: TransportConnect,
pub async fn connect_with<C>(
self,
connect: &C,
) -> Result<<F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Provider, RpcError<TransportErrorKind>>where
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
C: TransportConnect,
Finish the layer stack by providing a TransportConnect instance.
Sourcepub async fn connect_pubsub_with<C>(
self,
connect: C,
) -> Result<<F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Provider, RpcError<TransportErrorKind>>where
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
C: PubSubConnect,
Available on crate feature pubsub only.
pub async fn connect_pubsub_with<C>(
self,
connect: C,
) -> Result<<F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Provider, RpcError<TransportErrorKind>>where
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
C: PubSubConnect,
pubsub only.Finish the layer stack by providing a PubSubConnect instance,
producing a Provider with pubsub capabilities.
Sourcepub async fn connect_ws(
self,
connect: WsConnect,
) -> Result<<F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Provider, RpcError<TransportErrorKind>>where
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
Available on crate feature ws-base only.
pub async fn connect_ws(
self,
connect: WsConnect,
) -> Result<<F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Provider, RpcError<TransportErrorKind>>where
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
ws-base only.Build this provider with a websocket connection.
Sourcepub async fn connect_ipc<T>(
self,
connect: IpcConnect<T>,
) -> Result<<F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Provider, RpcError<TransportErrorKind>>where
IpcConnect<T>: PubSubConnect,
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
Available on crate feature ipc only.
pub async fn connect_ipc<T>(
self,
connect: IpcConnect<T>,
) -> Result<<F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Provider, RpcError<TransportErrorKind>>where
IpcConnect<T>: PubSubConnect,
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
ipc only.Build this provider with an IPC connection.
Sourcepub fn connect_http(
self,
url: Url,
) -> <F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
Available on crate feature reqwest and not (WASI and WASIp1) only.
pub fn connect_http(
self,
url: Url,
) -> <F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
reqwest and not (WASI and WASIp1) only.Build this provider with an Reqwest HTTP transport.
Sourcepub fn connect_reqwest<C>(
self,
client: C,
url: Url,
) -> <F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
C: Into<Client>,
Available on crate feature reqwest and not (WASI and WASIp1) only.
pub fn connect_reqwest<C>(
self,
client: C,
url: Url,
) -> <F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
C: Into<Client>,
reqwest and not (WASI and WASIp1) only.Build this provider with a pre-built Reqwest client.
Sourcepub fn with_reqwest<B>(
self,
url: Url,
builder: B,
) -> <F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
B: FnOnce(ClientBuilder) -> Client,
Available on crate feature reqwest and not (WASI and WASIp1) only.
pub fn with_reqwest<B>(
self,
url: Url,
builder: B,
) -> <F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
B: FnOnce(ClientBuilder) -> Client,
reqwest and not (WASI and WASIp1) only.Build this provider with a provided Reqwest client builder.
Sourcepub fn connect_hyper_http(
self,
url: Url,
) -> <F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
Available on crate feature hyper only.
pub fn connect_hyper_http(
self,
url: Url,
) -> <F as ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<RootProvider<N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<RootProvider<N>, N>>::Provider, N>,
N: Network,
hyper only.Build this provider with an Hyper HTTP transport.
Sourceimpl<L, F, N> ProviderBuilder<L, F, N>where
N: Network,
impl<L, F, N> ProviderBuilder<L, F, N>where
N: Network,
Sourcepub fn connect_anvil(
self,
) -> <F as ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>>::Providerwhere
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>,
L: ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>,
Available on crate features anvil-node only.
pub fn connect_anvil(
self,
) -> <F as ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>>::Providerwhere
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>,
L: ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>,
anvil-node only.Build this provider with anvil, using the BoxTransport.
This method requires the anvil-node feature on alloy-provider.
When using the alloy meta-crate, enable provider-anvil-node, or
combine providers with node-bindings.
Sourcepub fn connect_anvil_with_wallet(
self,
) -> <JoinFill<F, WalletFiller<EthereumWallet>> as ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>>::Providerwhere
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>,
L: ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>,
EthereumWallet: NetworkWallet<N>,
Available on crate features anvil-node only.
pub fn connect_anvil_with_wallet(
self,
) -> <JoinFill<F, WalletFiller<EthereumWallet>> as ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>>::Providerwhere
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>,
L: ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>,
EthereumWallet: NetworkWallet<N>,
anvil-node only.Build this provider with anvil, using the BoxTransport. This function configures a wallet backed by anvil keys, and is intended for use in tests.
This method requires the anvil-node feature on alloy-provider.
When using the alloy meta-crate, enable provider-anvil-node, or
combine providers with node-bindings.
Sourcepub fn connect_anvil_with_config(
self,
f: impl FnOnce(Anvil) -> Anvil,
) -> <F as ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>>::Providerwhere
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>,
L: ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>,
Available on crate features anvil-node only.
pub fn connect_anvil_with_config(
self,
f: impl FnOnce(Anvil) -> Anvil,
) -> <F as ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>>::Providerwhere
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>,
L: ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>,
anvil-node only.Build this provider with anvil, using the BoxTransport. The given function is used to configure the anvil instance.
This method requires the anvil-node feature on alloy-provider.
When using the alloy meta-crate, enable provider-anvil-node, or
combine providers with node-bindings.
Sourcepub fn on_anvil_with_config(
self,
f: impl FnOnce(Anvil) -> Anvil,
) -> <F as ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>,
👎Deprecated since 0.12.6: use connect_anvil_with_config instead
Available on crate features anvil-node only.
pub fn on_anvil_with_config(
self,
f: impl FnOnce(Anvil) -> Anvil,
) -> <F as ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>>::Providerwhere
L: ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>,
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>,
use connect_anvil_with_config instead
anvil-node only.Build this provider with anvil, using the BoxTransport. The given function is used to configure the anvil instance.
This method requires the anvil-node feature on alloy-provider.
When using the alloy meta-crate, enable provider-anvil-node, or
combine providers with node-bindings.
Sourcepub fn connect_anvil_with_wallet_and_config(
self,
f: impl FnOnce(Anvil) -> Anvil,
) -> Result<<JoinFill<F, WalletFiller<EthereumWallet>> as ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>>::Provider, NodeError>where
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>,
L: ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>,
EthereumWallet: NetworkWallet<N>,
Available on crate features anvil-node only.
pub fn connect_anvil_with_wallet_and_config(
self,
f: impl FnOnce(Anvil) -> Anvil,
) -> Result<<JoinFill<F, WalletFiller<EthereumWallet>> as ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>>::Provider, NodeError>where
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>,
L: ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>,
EthereumWallet: NetworkWallet<N>,
anvil-node only.Build this provider with anvil, using the BoxTransport.
This calls try_on_anvil_with_wallet_and_config and panics on error.
This method requires the anvil-node feature on alloy-provider.
When using the alloy meta-crate, enable provider-anvil-node, or
combine providers with node-bindings.
Sourcepub fn on_anvil_with_wallet_and_config(
self,
f: impl FnOnce(Anvil) -> Anvil,
) -> Result<<JoinFill<F, WalletFiller<EthereumWallet>> as ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>>::Provider, NodeError>where
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>,
L: ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>,
EthereumWallet: NetworkWallet<N>,
👎Deprecated since 0.12.6: use connect_anvil_with_wallet_and_config instead
Available on crate features anvil-node only.
pub fn on_anvil_with_wallet_and_config(
self,
f: impl FnOnce(Anvil) -> Anvil,
) -> Result<<JoinFill<F, WalletFiller<EthereumWallet>> as ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>>::Provider, NodeError>where
F: TxFiller<N> + ProviderLayer<<L as ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>>::Provider, N>,
L: ProviderLayer<AnvilProvider<RootProvider<N>, N>, N>,
EthereumWallet: NetworkWallet<N>,
use connect_anvil_with_wallet_and_config instead
anvil-node only.Build this provider with anvil, using the BoxTransport.
This calls try_on_anvil_with_wallet_and_config and panics on error.
This method requires the anvil-node feature on alloy-provider.
When using the alloy meta-crate, enable provider-anvil-node, or
combine providers with node-bindings.